==> Paws-0.30.tar.gz: Paws-0.30/lib/Paws/GameLift/DescribeRuntimeConfiguration.pm <==

package Paws::GameLift::DescribeRuntimeConfiguration;
  use Moose;
  has FleetId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeRuntimeConfiguration');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::GameLift::DescribeRuntimeConfigurationOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::GameLift::DescribeRuntimeConfiguration - Arguments for method DescribeRuntimeConfiguration on Paws::GameLift

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeRuntimeConfiguration on the 
Amazon GameLift service. Use the attributes of this class
as arguments to method DescribeRuntimeConfiguration.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeRuntimeConfiguration.

As an example:

  $service_obj->DescribeRuntimeConfiguration(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> FleetId => Str

Unique identifier of the fleet to get the runtime configuration for.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeRuntimeConfiguration in L<Paws::GameLift>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.33.tar.gz: Paws-0.33/lib/Paws/GameLift/DescribeRuntimeConfiguration.pm <==

package Paws::GameLift::DescribeRuntimeConfiguration;
  use Moose;
  has FleetId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeRuntimeConfiguration');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::GameLift::DescribeRuntimeConfigurationOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::GameLift::DescribeRuntimeConfiguration - Arguments for method DescribeRuntimeConfiguration on Paws::GameLift

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeRuntimeConfiguration on the 
Amazon GameLift service. Use the attributes of this class
as arguments to method DescribeRuntimeConfiguration.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeRuntimeConfiguration.

As an example:

  $service_obj->DescribeRuntimeConfiguration(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> FleetId => Str

Unique identifier for a fleet to get the runtime configuration for.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeRuntimeConfiguration in L<Paws::GameLift>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
